@@ -154,24 +154,48 @@ def sanitize_name(name: str, filename_scheme: Optional[str] = None) -> str:
 
     filename_scheme = filename_scheme or config_helper.get_or_default_filename_scheme()
 
+    # First replace umlaute
+    for a, b in {"ä": "a", "ö": "o", "ü": "u"}.items():
+        name = name.replace(a, b)
+        name = name.replace(a.upper(), b.upper())
+
+    # Now start to add chars that don't fit.
+    char_string = ""
+
     if filename_scheme >= "0":
-        name = name.replace("/", "-")
+        if is_windows:
+            char_string += "<>:\"/\\|?*"
+        else:
+            char_string += "/"
 
     if filename_scheme >= "1":
         # Now replace any remaining funny symbols with a `?`
         name = name.encode("ascii", errors="replace").decode()
 
-        # Now replace all known "bad" ascii chars with a symbol
-        char_mapping = {
-            ".": string.whitespace + "_" + r"""#%&/:;<=>@\^`|~-$"'?""",
-            "(": "[{",
-            ")": "]}",
-        }
+        char_string += r"""!"#$%&'()*+,/:;<=>?@[\]^`{|}~"""
 
-        for char, mapping in char_mapping.items():
-            name = name.translate(str.maketrans(mapping, char * len(mapping)))
+    name = name.translate(str.maketrans(char_string, "\0" * len(char_string)))
 
-    return name
+    # This is probably a suboptimal solution, but it works…
+    final = list(name)
+
+    whitespaces = set(string.whitespace + "_")
+    i = 0
+    while i < len(final):
+        char = final[i]
+
+        if char == "\0" or char in whitespaces:
+            final.pop(i)
+
+            if char in whitespaces:
+                if i < len(final):
+                    final[i] = final[i].upper()
+
+            continue
+
+        i += 1
+
+    return "".join(final)
 
 
 def get_input(message: str, allowed: Set[str]) -> str:
